@@ -9,7 +9,9 @@ import Data.List (intersperse)
 import Control.Monad.State (evalState, State, get, put)
 
 data Properties = NoLine | SingleLine | DoubleLine
+                deriving (Show)
 data Header h = Header h | Group Properties [Header h]
+              deriving (Show)
 
 -- |
 -- > example = Table
@@ -39,28 +41,7 @@ data Header h = Header h | Group Properties [Header h]
 -- > -- B 2 ||    better | no chance ||    crawling |     amazing
 -- > -- B 3 ||       meh |   well... ||  worst ever |          ok
 data Table rh ch a = Table (Header rh) (Header ch) [[a]]
-
--- ----------------------------------------------------------------------
---
--- ----------------------------------------------------------------------
-
-{-
--- | A 'Table' of "FancyCell"
-type FancyTable d a = Table (FancyCell d a)
-
--- | 'FancyCell' @decorations a@ is a table cell that is associated with
---   decorations of your choosing (for example, a cell colour) as well as
---   instructions to merge that cell with its neighbours down or to the
---   right.  We include special versions of the rendering functions that
---   recognise the merge instructions, but you will have to supply the
---   code that deals with the decorations.
-type FancyCell decorations a = (a, Maybe decorations, Maybe MergeInfo)
-
-
-data MergeInfo = MergeInfo { mergeDown :: Int
-                           , mergeRight :: Int
-                           }
--}
+                   deriving (Show)
 
 -- ----------------------------------------------------------------------
 -- * Helper functions for rendering
@@ -147,6 +128,7 @@ squish decorator f h = helper $ flattenHeader h
 -- >   +.+ row "B 2" ["better", "no chance", "crawling", "amazing"]
 -- >   +.+ row "B 3" ["meh",  "well...", "worst ever", "ok"]
 data SemiTable h a = SemiTable (Header h) [a]
+                   deriving (Show)
 
 empty :: Table rh ch a
 empty = Table (Group NoLine []) (Group NoLine []) []
@@ -168,7 +150,7 @@ beside :: Properties -> Table rh ch a -> SemiTable ch a -> Table rh ch a
 beside prop (Table rows cols1 data1)
             (SemiTable  cols2 data2) =
   Table rows (Group prop [cols1, cols2])
-             (zipWith (++) data1 [data2])
+             (zipWith (\xs x -> xs ++ [x]) data1 data2)
 
 below :: Properties -> Table rh ch a -> SemiTable rh a -> Table rh ch a
 below prop (Table     rows1 cols data1)
